local MAJOR, MINOR = "LibInventory-2.1", 6020201 -- 6.2.2 v1 -- 20444
local LibInventory = LibStub:NewLibrary(MAJOR, MINOR)

if not LibInventory then return end -- no need to update

-- to populate the cache with the auction house, run this when the AH is opened:
-- /script QueryAuctionItems("", nil, nil, 0, 0, 0, 0, 0, 0, true)

-- /script local maxid = 0; for i = 97000, 98000 do if GetItemIcon(i) then maxid = i end end; print(maxid)

-- -----
-- local upvalues
-- -----
local _G = getfenv(0)

local collectgarbage		= _G.collectgarbage
local ipairs				= _G.ipairs
local min					= _G.min
local next					= _G.next
local pairs					= _G.pairs
local select				= _G.select
local tonumber				= _G.tonumber
local tostring				= _G.tostring
local type					= _G.type

local GetItemIcon			= _G.GetItemIcon
local GetItemInfo			= _G.GetItemInfo
local InCombatLockdown		= _G.InCombatLockdown

local bit_band				= _G.bit.band
local math_floor			= _G.math.floor
local math_pow				= _G.math.pow
local math_random			= _G.math.random
local string_byte			= _G.string.byte
local string_match			= _G.string.match
local table_concat			= _G.table.concat
local table_insert			= _G.table.insert
local table_remove			= _G.table.remove
local table_sort			= _G.table.sort
local table_wipe			= _G.table.wipe

local CallbackHandler = _G.LibStub:GetLibrary("CallbackHandler-1.0")

-- -----
-- lib variables
-- -----
LibInventory.frame					= LibInventory.frame					or _G.CreateFrame("Frame", "LibInventory21Frame") -- our event frame
LibInventory.callbacks				= LibInventory.callbacks				or CallbackHandler:New(LibInventory)

LibInventory.items					= LibInventory.items					or {} -- { [id] = true, ... }
LibInventory.itemsRescan			= LibInventory.itemsRescan				or {} -- { [id], ... }
LibInventory.itemsValidIdsClient	= LibInventory.itemsValidIdsClient		or {} -- { [id], ... }
LibInventory.itemsValidIdsServer	= LibInventory.itemsValidIdsServer		or {} -- { [id], ... }
LibInventory.itemsLastScanned		= LibInventory.itemsLastScanned			or 0
LibInventory.count_known			= LibInventory.count_known				or 0
LibInventory.count_total			= LibInventory.count_total				or 0
LibInventory.highest_id				= LibInventory.highest_id				or 0
LibInventory.types_base				= LibInventory.types_base				or {}
LibInventory.types_sub				= LibInventory.types_sub				or {}
LibInventory.types_slot				= LibInventory.types_slot				or {}
LibInventory.types_tree				= LibInventory.types_tree				or {[1] = LibInventory.types_base}

LibInventory.itemStatsTable			= LibInventory.itemStatsTable			or {}

LibInventory.STATUS_INITIALIZING	= LibInventory.STATUS_INITIALIZING		or "INITIALIZING"
LibInventory.STATUS_QUERYING_CLIENT	= LibInventory.STATUS_QUERYING_CLIENT	or "QUERYING (Client)"
LibInventory.STATUS_SCANNING_CLIENT	= LibInventory.STATUS_SCANNING_CLIENT	or "SCANNING (Client)"
LibInventory.STATUS_QUERYING_SERVER	= LibInventory.STATUS_QUERYING_SERVER	or "QUERYING (Server)"
LibInventory.STATUS_SCANNING_SERVER	= LibInventory.STATUS_SCANNING_SERVER	or "SCANNING (Server)"
LibInventory.STATUS_READY			= LibInventory.STATUS_READY				or "READY"
LibInventory.status					= LibInventory.status					or LibInventory.STATUS_INITIALIZING

-- temporary hack; insert some known server-side items
-- LibInventory.itemsValidIdsServer = {
	-- 93364, -- Refined Crystallized Dread
	-- 93365, -- Refined Crystallized Terror
	-- 93366, -- Refined Crystallized Horror
	-- 97309, -- Crystallized Horror
-- }

-- -----
-- locale stuff
-- -----
LibInventory.LOCALE_INVTYPE_OTHER = "Other"

local client_locale = _G.GetLocale()
if client_locale == "deDE" then
	LibInventory.LOCALE_INVTYPE_OTHER = "Sonstiges"
end


-- -----
-- local helpers
-- -----
local CONST_ITEMS_PER_SCAN_CLIENT = 50
local CONST_ITEMS_PER_SCAN_SERVER = 10
local CONST_ITEMS_MAX_ID		= 130943 -- 6.2.2 (20444)
local CONST_ITEMS_MAX_ID_CLIENT	= 130943 -- 6.2.2 (20444)

-- item.db2 dump for 20444: 105242 items
local itemsValid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
-- item-sparse.db2 dump for 20444: 86300 items
local itemsClient = "\0\0\1\1\252\220\221\29\0\192\144\4\8\0\176\193\1\78\12\75\0\0\32\128\135\7\3\0\0\120\0\0\0\0\0\112\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\32\32\0\0\0\0\0\0\0\0\0\0\0\0\0\0\1\0\12\0\0\0\0\0\0\0\0\0\0\64\0\0\0\0\0\0\0\96\226\220\127\239\169\15\244\191\127\245\127\24\191\26\158\245\253\191\239\255\169\248\219\13\96\175\255\253\239\0\190\3\0\80\0\8\160\119\157\13\0\0\0\0\0\158\7\0\0\0\11\65\15\0\0\110\227\93\127\244\191\255\126\63\0\0\0\140\253\33\143\206\184\237\54\118\114\0\0\208\253\239\171\251\94\78\249\255\127\117\171\244\119\191\61\253\255\87\247\247\239\143\9\5\4\144\33\0\0\0\40\202\16\128\33\208\16\136\132\128\240\240\128\113\239\191\243\127\255\255\255\233\235\235\255\255\255\255\255\255\204\60\27\0\0\4\0\48\32\64\17\246\247\247\67\108\146\254\62\238\187\248\244\155\191\223\239\96\135\183\247\219\13\62\185\211\255\191\255\251\235\255\89\128\14\6\220\255\255\231\255\61\175\239\79\191\207\207\236\255\255\121\0\0\0\0\107\255\255\255\255\231\37\255\223\182\255\255\207\255\223\255\255\255\255\204\255\255\0\63\141\255\207\255\255\111\249\255\255\153\255\190\191\255\207\255\127\174\63\129\133\159\106\170\121\254\60\254\255\15\246\243\194\255\249\255\255\255\231\255\254\183\61\254\255\61\248\54\252\118\255\255\255\255\255\252\128\190\255\103\221\243\217\99\247\239\127\0\64\108\16\2\68\1\192\191\255\255\253\255\255\255\191\235\125\255\145\254\251\191\223\255\255\253\255\255\223\239\253\221\191\148\255\127\255\222\255\253\255\127\214\254\255\251\251\191\255\223\35\123\191\1\134\0\224\239\127\255\243\255\255\255\255\119\255\255\223\255\255\255\235\191\31\112\238\255\255\255\255\253\231\125\239\255\135\255\255\255\255\255\255\255\255\239\254\223\10\127\191\255\255\255\236\255\255\255\255\255\255\255\255\255\255\255\31\254\255\255\255\255\255\254\191\255\255\255\255\255\15\0\0\0\0\0\64\152\0\16\64\192\255\255\255\255\1\32\0\191\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\181\187\255\253\243\255\255\251\223\255\239\255\255\251\255\255\255\191\255\199\249\255\255\255\255\240\255\255\253\251\126\219\190\237\251\255\255\255\127\253\255\211\117\245\255\255\255\255\255\179\255\255\191\253\47\254\255\255\229\254\195\255\255\191\221\191\223\179\223\255\239\182\228\127\143\255\63\160\142\238\255\223\255\255\249\255\252\255\159\240\75\0\0\248\211\255\255\255\255\255\31\128\255\255\255\69\254\71\4\0\36\242\255\255\233\255\255\223\239\247\101\255\231\24\254\255\255\213\255\196\255\255\255\255\51\202\255\207\253\247\255\52\132\240\255\255\255\143\187\255\255\255\255\54\224\132\25\4\97\127\0\0\48\0\252\255\248\255\255\255\255\255\255\255\255\191\255\255\255\127\255\223\249\15\0\1\0\112\0\128\254\239\248\255\255\0\0\56\0\128\0\0\240\255\255\255\255\255\127\253\3\0\248\127\231\143\63\0\224\255\159\127\255\63\108\79\135\224\247\159\223\255\7\255\255\255\255\255\253\223\255\254\255\255\95\255\255\255\255\255\255\255\237\255\255\255\255\255\227\68\250\255\255\255\255\127\255\255\255\255\255\239\255\223\255\161\255\159\87\254\255\255\124\251\255\1\176\255\119\255\255\255\29\96\240\248\255\255\255\15\0\254\239\255\5\0\2\0\192\127\250\255\15\224\7\0\252\1\224\255\255\247\255\63\0\0\6\0\224\255\255\253\255\255\255\31\254\255\224\127\0\10\0\32\2\0\124\0\224\1\0\126\0\64\1\0\254\251\255\255\3\30\0\224\255\255\251\255\255\255\3\246\0\224\255\255\248\255\255\255\255\249\255\255\255\14\254\255\255\255\255\211\255\225\1\0\6\0\224\23\0\30\0\32\0\0\254\239\254\7\0\248\247\239\247\63\254\255\225\7\0\6\0\224\31\0\0\0\224\0\0\102\0\224\0\0\254\255\251\255\247\255\255\253\255\255\255\31\224\1\0\62\0\224\31\0\126\255\255\127\0\254\255\255\255\255\242\255\215\255\255\255\255\255\255\195\3\0\248\255\255\255\255\255\255\255\255\255\0\0\192\63\0\252\0\192\255\255\255\15\192\255\0\12\0\64\0\0\252\239\31\8\0\252\1\128\9\0\12\0\128\207\7\4\0\192\223\0\124\0\64\0\0\124\0\192\13\0\12\0\0\254\7\32\0\0\0\0\0\0\0\68\104\48\0\0\0\0\0\0\0\0\0\252\8\0\248\89\0\16\128\1\1\0\0\0\32\0\0\0\24\0\0\128\0\0\0\0\0\0\128\16\7\0\24\4\22\16\32\34\128\0\191\255\255\255\3\252\255\239\251\159\255\255\255\0\0\252\255\79\254\255\255\255\255\254\255\255\251\255\127\255\255\255\15\0\252\255\199\246\254\239\255\255\247\31\252\255\255\1\254\255\255\255\255\251\3\224\127\0\198\3\96\0\0\254\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\127\255\255\255\255\255\255\255\255\255\255\63\2\0\224\223\7\254\255\239\255\255\255\255\255\255\255\255\255\225\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\247\3\254\255\255\255\31\2\0\224\255\255\255\255\227\255\63\218\0\224\127\226\247\7\96\0\0\254\255\39\0\0\254\255\235\127\255\247\191\241\255\3\248\255\255\255\249\255\0\224\235\255\255\255\255\255\0\254\255\231\255\255\255\255\255\255\0\254\254\255\127\0\2\0\0\0\0\0\0\224\3\0\14\0\96\0\0\2\0\96\0\0\234\6\224\0\0\2\0\160\47\0\240\255\235\255\255\255\255\0\254\249\135\255\31\254\0\96\119\0\6\0\96\63\0\254\7\224\255\237\24\0\0\0\0\238\6\160\255\7\254\255\111\0\0\56\0\224\255\254\2\0\224\252\15\2\0\0\0\0\254\3\224\32\0\254\255\225\255\7\254\1\32\217\118\58\0\96\0\0\254\255\225\255\7\248\0\224\7\0\222\255\255\255\215\255\255\255\255\15\254\1\224\255\255\255\255\255\255\7\254\255\255\255\255\255\255\255\255\255\255\255\191\3\0\6\0\224\255\7\2\0\0\0\0\14\0\128\225\0\254\251\207\255\255\199\255\255\0\0\238\221\108\0\0\124\226\245\255\239\253\0\224\0\0\186\239\175\255\63\248\71\239\255\0\0\0\0\0\0\218\127\224\255\63\126\0\224\190\0\254\255\255\239\255\255\127\96\0\0\222\255\255\255\255\255\254\31\160\25\184\255\253\229\255\238\255\255\255\255\255\1\0\64\0\248\228\207\7\0\254\195\110\131\191\252\243\231\253\250\255\255\255\255\255\255\253\239\239\223\255\247\127\255\255\255\255\255\11\124\239\255\255\255\127\254\159\3\0\0\254\127\63\0\0\254\1\0\120\159\255\125\136\255\251\255\255\255\255\255\159\1\96\0\0\254\254\255\127\255\255\255\127\255\246\253\255\167\3\0\2\0\224\1\0\0\0\128\2\0\0\0\0\0\1\0\0\96\0\0\248\190\255\159\254\255\223\255\109\59\255\223\255\1\0\0\158\203\255\254\255\223\255\255\191\224\127\255\255\255\255\1\224\2\0\2\0\224\1\0\254\0\0\0\0\236\247\255\254\223\255\191\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\0\0\248\255\31\160\252\255\255\255\255\255\255\255\255\255\251\255\255\255\255\3\182\135\255\255\247\255\191\255\255\239\255\254\253\255\255\249\255\255\255\255\255\0\0\0\0\254\3\224\255\255\255\255\255\255\255\255\255\17\255\231\239\255\255\159\0\0\228\255\255\255\255\255\255\255\255\255\255\127\0\0\254\255\7\0\0\254\255\255\255\255\255\254\224\255\255\255\255\255\255\255\255\255\255\255\255\254\255\255\255\255\255\255\255\255\255\255\255\255\255\3\254\255\255\255\255\255\255\255\255\255\255\255\255\255\255\223\255\247\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\253\255\255\255\255\255\255\255\255\255\255\255\127\255\231\63\0\254\255\255\255\255\255\255\255\255\255\255\127\224\7\0\254\255\255\255\255\127\126\224\223\255\255\255\255\7\0\254\255\255\255\255\255\1\96\2\192\255\255\14\128\1\30\0\0\224\7\0\0\0\0\0\224\7\8\176\0\254\99\255\0\0\250\127\96\0\0\6\0\224\247\251\255\95\112\255\255\191\253\255\255\25\181\243\255\255\159\175\255\101\207\255\124\175\247\63\111\255\254\252\249\166\255\53\95\0\0\254\0\96\0\0\254\255\254\255\255\255\255\255\255\255\255\255\255\15\0\254\1\224\255\255\255\255\255\255\255\255\255\255\255\1\254\255\255\255\255\255\255\255\255\255\255\255\255\255\127\255\255\255\255\127\254\255\255\255\63\2\0\224\247\115\56\0\32\0\0\0\0\224\255\191\15\0\224\0\0\0\0\0\0\0\0\0\224\63\0\254\31\128\219\5\8\0\128\0\0\254\54\96\0\0\2\0\0\0\0\0\0\224\15\0\6\0\32\0\0\234\159\223\234\235\223\158\235\3\0\6\0\32\0\0\254\255\224\255\255\255\250\255\255\255\255\255\31\0\0\2\0\96\0\0\0\3\0\0\0\98\0\248\31\0\2\0\64\0\0\190\1\32\0\0\0\0\32\0\0\254\0\0\0\0\6\0\224\0\0\0\0\224\255\129\128\31\32\0\0\254\0\224\255\255\255\255\255\21\0\254\239\255\255\247\255\255\255\255\251\255\255\255\255\255\255\255\251\191\158\223\255\255\255\253\255\255\255\255\255\255\255\255\7\0\78\0\224\239\178\255\15\224\219\255\247\255\255\225\255\239\255\255\255\255\255\231\255\147\255\227\255\255\255\127\254\255\255\255\255\255\255\255\255\255\1\0\160\0\0\2\0\192\255\255\3\9\128\6\0\254\159\239\255\255\255\239\191\127\0\252\255\255\255\255\253\255\255\255\255\254\3\96\0\0\254\223\255\253\255\255\255\255\255\255\207\223\255\255\252\253\255\255\255\191\255\255\255\255\255\119\0\224\227\255\255\63\32\0\0\12\4\0\255\255\255\255\255\255\255\255\255\255\255\255\255\255\31\0\0\2\0\0\0\0\254\255\255\255\255\127\0\0\0\0\248\255\255\63\0\254\248\255\255\239\183\255\247\247\191\255\255\255\255\231\223\247\255\255\255\223\127\166\226\255\255\255\127\253\255\255\255\255\255\255\247\255\255\255\255\255\47\32\224\255\255\255\255\255\255\255\255\239\255\31\12\240\255\3\0\0\192\0\32\0\0\1\0\0\0\128\245\255\253\255\255\247\174\255\255\207\255\215\247\254\199\254\255\255\255\235\254\255\255\255\255\255\63\0\192\255\254\255\255\255\255\255\255\255\255\255\255\255\255\159\255\231\241\191\255\253\15\0\0\208\255\219\255\238\253\255\255\255\255\127\251\255\255\246\255\255\127\254\125\255\109\247\255\255\255\255\255\255\253\241\7\0\0\192\0\0\0\204\255\255\248\190\255\255\255\251\228\255\127\248\255\255\255\191\20\159\255\255\255\245\223\255\255\255\254\255\255\255\255\255\255\255\255\255\255\255\255\3\0\40\2\248\255\254\255\255\255\255\255\215\255\255\255\143\240\247\167\247\255\255\255\255\255\7\196\208\14\192\255\255\255\255\255\255\47\255\127\251\255\191\252\231\223\242\129\255\251\127\112\253\255\255\254\255\31\251\255\255\255\255\241\253\255\159\159\0\64\252\255\255\255\255\199\0\0\232\239\253\255\255\255\255\255\255\223\7\252\255\63\255\255\255\255\255\191\255\169\255\255\254\255\255\253\255\255\255\255\255\255\247\251\255\239\253\255\255\255\255\191\255\255\191\255\255\255\255\143\255\255\249\207\255\255\255\255\255\127\237\245\255\255\254\207\240\247\255\255\251\252\255\219\255\255\255\255\255\255\255\255\255\247\127\253\191\255\239\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\127\253\255\255\127\234\255\255\255\255\255\255\239\255\255\255\255\253\255\255\243\255\255\125\223\255\223\255\255\255\255\255\255\159\241\23\255\192\255\117\100\255\94\112\238\255\255\191\255\255\255\255\255\255\111\191\255\175\167\215\254\223\247\255\255\127\249\247\255\251\253\159\95\255\254\127\255\255\255\255\255\255\255\255\191\255\137\255\255\255\127\255\255\127\62\32\255\255\252\243\124\97\215\155\36\255\167\255\255\255\255\255\255\241\255\255\255\255\255\253\111\239\127\255\255\190\127\48\192\255\63\135\159\1\16\192\159\31\214\239\1\248\255\221\255\255\255\223\255\255\255\255\255\251\255\255\255\227\255\255\255\255\187\255\255\255\255\231\255\247\255\255\255\255\127\255\255\255\63\4\226\255\255\223\255\249\254\255\255\255\252\245\255\255\255\255\255\255\255\255\185\255\127\219\39\0\238\247\255\65\208\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\239\254\255\127\255\255\255\185\255\255\243\199\243\255\255\255\255\248\255\223\255\63\254\255\119\255\125\239\255\255\255\255\67\222\255\255\255\255\31\254\127\253\255\63\127\250\243\191\191\111\247\255\255\255\255\255\255\255\255\255\255\255\255\255\251\255\255\255\255\159\127\0\0\0\0\0\0\0\0\0\0\0\0\0\0\112\8\0\0\0\0\0\0\4\0\0\0\0\0\0\0\0\0\0\8\0\0\0\0\128\8\0\0\0\0\0\0\0\0\0\0\128\1\0\0\0\0\0\0\0\0\0\8\0\0\0\0\0\0\0\0\0\0\0\0\64\0\0\0\0\0\0\0\0\0\0\2\0\0\0\0\0\128\0\0\0\0\0\0\4\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\8\0\0\2\0\0\0\0\0\0\0\0\0\0\0\16\0\0\0\0\0\0\0\0\56\224\143\255\239\255\255\247\255\255\255\255\221\127\127\255\255\255\253\255\255\1\0\0\0\32\0\0\0\0\192\255\253\255\255\223\251\255\255\239\255\255\255\255\255\255\255\255\255\223\255\255\127\253\251\255\247\255\224\223\255\255\255\223\255\255\255\251\255\255\31\0\16\128\255\255\15\0\0\192\254\227\211\254\255\251\7\0\0\252\219\248\239\171\255\255\255\239\255\255\255\3\126\255\255\255\255\255\255\239\255\231\255\254\255\255\255\223\252\255\255\253\207\255\223\255\255\255\255\255\255\255\255\127\255\191\127\63\255\255\255\255\255\255\255\237\255\255\255\255\255\223\255\255\255\255\255\127\253\255\255\255\253\255\255\255\255\255\127\254\255\255\255\255\255\255\223\255\127\255\255\255\255\255\255\255\39\243\1\192\253\245\255\247\255\255\223\238\255\255\255\255\255\255\255\255\255\255\247\255\255\255\255\255\255\251\253\255\255\255\255\255\255\255\253\247\255\127\255\255\255\255\255\127\255\255\255\255\239\255\159\255\255\255\255\255\223\255\255\255\127\255\1\14\4\27\2\212\191\223\255\191\3\255\255\255\255\255\255\12\127\207\223\255\255\250\255\255\255\131\1\0\16\0\128\0\16\10\21\254\128\243\255\255\255\119\255\255\255\255\223\255\253\126\35\8\0\1\0\0\72\0\0\0\240\251\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\223\255\255\255\255\255\127\255\255\251\255\255\127\193\191\138\113\254\255\255\255\255\255\239\255\255\255\247\255\223\255\239\255\255\251\255\191\127\255\2\254\11\240\63\251\31\238\55\255\15\252\229\7\223\255\255\127\255\254\254\239\253\127\244\255\255\255\255\31\222\224\63\255\199\143\255\255\255\216\191\201\255\255\255\255\255\255\255\255\223\242\204\255\255\255\255\111\255\255\255\239\255\255\255\255\127\254\159\255\239\253\235\255\255\255\255\255\255\255\255\255\255\255\255\255\255\184\255\255\255\255\255\255\255\255\255\255\251\255\255\255\15\255\255\255\255\255\239\250\250\252\255\127\207\175\255\175\255\255\119\238\255\255\255\230\255\255\255\255\255\255\255\255\255\241\255\255\127\144\248\255\255\255\255\191\255\255\255\255\255\127\96\242\255\255\255\239\223\255\250\255\255\255\127\255\255\255\255\189\255\255\191\251\255\255\255\200\255\223\255\255\1\248\255\255\255\255\255\254\255\255\255\193\255\243\253\255\253\255\255\255\255\255\255\255\255\255\255\255\252\251\255\251\255\255\255\255\255\255\255\255\255\255\255\191\255\255\255\255\255\255\223\255\255\127\255\255\255\255\255\255\253\255\255\255\127\255\243\127\255\255\255\255\127\252\255\127\255\182\255\239\247\255\123\187\255\255\253\127\85\87\237\255\255\255\249\163\193\255\127\255\245\255\255\239\255\255\255\251\255\191\255\248\183\255\255\255\191\255\255\255\255\191\255\249\255\255\63\255\255\0\134\192\255\183\246\0\0\240\63\254\15\244\255\255\127\232\251\223\251\255\223\254\155\255\120\255\221\118\255\215\111\125\255\248\255\60\112\0\239\16\126\228\246\251\255\255\255\255\255\243\127\159\207\255\27\255\255\253\255\254\255\255\255\255\255\255\255\255\255\255\255\127\255\255\255\255\255\255\191\255\206\255\31\255\255\231\197\255\255\65\120\254\63\252\246\0\0\240\255\255\255\255\255\255\255\255\255\255\255\255\255\39\254\192\26\189\255\222\255\255\239\255\255\255\255\255\255\255\255\255\255\255\255\255\255\251\191\3\5\209\135\255\255\255\133\15\255\253\127\63\255\15\60\223\239\255\255\255\31\176\254\255\255\255\255\255\255\254\255\255\255\241\55\0\0\0\0\0\0\64\0\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\0\0\248\255\255\63\191\0\96\192\83\255\31\254\255\255\255\245\247\255\255\255\5\0\128\223\151\247\255\188\111\255\127\239\3\128\0\252\255\255\121\255\255\255\235\127\224\255\251\255\254\255\255\128\192\255\251\255\255\255\255\255\255\255\207\252\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\79\247\255\255\255\255\255\255\255\255\255\255\255\247\255\243\255\255\255\255\253\255\255\255\127\255\255\255\255\191\255\255\255\255\255\255\255\255\255\255\248\255\253\191\255\127\237\255\251\223\11\128\10\0\0\20\190\255\255\255\255\255\255\239\253\255\255\255\255\251\253\247\254\255\95\184\182\183\7\255\255\255\225\227\232\254\231\255\255\254\255\191\255\255\255\253\255\255\255\255\255\255\255\211\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\206\251\248\239\253\30\255\255\255\255\191\15\224\255\255\239\255\255\127\244\191\251\255\255\255\255\59\3\253\255\219\255\254\255\255\255\255\255\255\251\255\255\255\252\151\255\63\251\225\223\253\255\254\255\255\255\255\255\255\255\255\255\255\254\255\253\255\255\255\255\199\255\63\193\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\227\127\15\252\250\255\253\239\119\111\252\255\255\255\255\255\255\255\255\255\255\255\173\127\255\255\221\255\255\255\255\255\255\255\255\255\255\127\205\255\255\255\253\223\239\255\255\255\133\215\191\255\61\251\191\7\248\255\237\255\62\192\255\223\255\255\1\232\129\255\255\251\255\62\224\127\243\255\159\15\255\19\126\62\226\56\255\255\241\255\238\255\255\187\251\127\120\253\227\255\251\255\127\255\255\255\191\62\249\255\255\191\255\255\159\248\255\95\145\13\128\131\163\255\223\255\255\255\253\111\248\215\255\240\113\246\255\255\241\242\215\255\255\255\239\197\95\255\127\224\255\213\255\255\255\253\127\255\251\255\191\255\253\255\251\255\253\255\255\255\243\255\251\251\255\255\207\95\199\255\252\158\255\245\63\214\127\127\175\253\255\239\171\255\255\255\175\185\255\217\255\254\234\250\255\255\127\252\255\255\223\255\255\255\255\255\255\255\255\63\252\55\127\255\238\255\255\127\191\255\255\79\255\255\255\255\255\255\255\191\127\255\255\255\255\255\255\191\255\255\255\254\255\255\255\255\127\248\127\255\255\255\255\255\255\255\129\255\239\255\255\251\254\255\255\127\79\12\250\255\255\255\255\255\255\239\255\127\255\255\255\255\255\191\231\247\15\255\254\64\248\255\255\255\255\243\255\255\252\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\191\255\255\255\255\255\127\255\255\255\255\255\247\255\255\255\7\252\255\255\255\255\251\255\255\255\255\255\255\239\255\255\241\255\247\127\255\159\167\255\237\255\255\255\159\212\255\255\255\255\255\255\195\7\254\255\255\255\23\26\0\250\239\255\255\255\255\255\255\254\255\255\63\194\221\255\255\112\255\143\255\255\248\251\143\255\255\244\207\219\255\191\255\255\190\239\254\255\47\255\231\254\231\251\190\207\239\123\223\239\222\123\239\251\252\255\255\255\255\255\251\254\190\255\63\246\255\255\190\239\195\123\239\151\127\171\255\239\251\190\247\125\223\251\254\191\255\95\231\217\255\255\255\253\255\255\254\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\191\255\255\255\239\187\123\239\253\247\190\239\125\239\187\247\255\239\255\255\255\199\246\247\190\255\255\255\255\255\191\255\221\253\127\239\189\247\187\190\247\189\239\251\126\223\119\251\190\239\128\255\123\191\239\251\255\255\127\192\255\255\255\139\248\255\255\127\174\255\227\251\255\14\248\255\255\255\239\251\255\223\59\239\251\189\247\222\123\239\255\255\127\239\189\255\239\203\191\255\243\251\254\255\255\255\249\239\255\247\255\255\205\125\239\254\232\247\121\158\55\243\255\189\239\239\125\127\239\253\190\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\167\247\171\255\255\255\255\255\255\255\255\255\63\255\255\254\255\255\255\255\63\226\6\232\255\255\255\255\255\255\255\125\223\255\255\127\0\0\4\248\255\255\243\253\31\252\255\255\255\127\255\255\189\255\255\183\239\127\3\89\253\255\223\255\255\255\255\7\239\255\255\255\255\255\255\255\255\255\191\255\255\255\255\255\255\255\255\255\255\255\173\187\127\191\255\239\239\247\247\255\15\248\255\225\255\215\129\255\191\254\255\253\252\255\255\255\255\247\247\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\159\255\207\255\255\255\255\255\239\111\175\255\255\254\191\255\255\255\255\255\255\127\255\223\191\239\255\255\255\191\199\255\255\255\255\253\246\255\255\255\255\254\255\123\206\255\247\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\15\255\255\223\255\120\191\255\223\255\255\255\255\255\255\247\255\255\255\255\255\63\248\247\207\255\255\251\251\127\215\252\255\255\255\255\255\255\255\251\125\123\159\237\127\255\255\255\255\255\249\131\166\79\47\160\255\15\246\254\250\255\239\255\255\255\255\255\255\251\126\255\244\255\255\255\255\255\253\255\255\255\126\174\255\247\255\246\255\255\255\255\243\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\127\255\253\255\255\255\255\255\255\255\255\223\255\255\255\255\191\255\255\255\255\255\255\255\255\251\255\255\251\255\255\95\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\247\255\255\255\31\252\255\7\189\251\255\255\255\247\255\255\253\255\255\255\127\255\255\255\247\248\255\213\0\192\255\223\255\255\255\255\255\254\255\255\255\247\255\255\255\127\255\255\255\255\228\255\123\255\255\255\255\255\255\255\255\255\255\255\255\255\255\239\255\255\255\255\255\255\255\255\255\255\255\31\4\253\255\222\255\187\191\255\252\7\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\192\3\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\254\127\124\174\55\96\252\255\255\255\255\255\16\155\127\251\155\252\43\68\159\31\32\254\223\249\255\255\255\255\255\255\255\255\255\255\15\251\223\239\207\127\48\253\255\254\253\254\255\255\251\159\255\15\33\31\254\255\31\124\254\255\255\223\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\3\0\0\0\0\0\0\0\4\0\248\255\255\255\255\255\255\255\255\127\255\251\250\255\255\3\16\255\251\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\249\255\255\255\255\255\255\255\255\255\255\255\4\248\191\0\255\255\255\255\255\255\255\127\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\191\162\170\170\255\255\255\255\255\255\255\255\255\255\255\255\255\255\127\255\255\255\255\255\255\255\191\255\255\255\255\255\255\255\255\255\255\255\170\42\170\186\173\250\255\255\191\170\255\255\255\85\85\85\85\255\255\255\171\232\255\255\127\255\255\255\255\255\255\255\95\255\87\85\85\85\253\171\250\255\255\255\255\175\255\251\63\254\255\255\255\255\253\255\127\249\255\255\255\255\255\255\127\255\87\85\65\31\0\224\127\236\243\128\42\0\170\170\42\170\170\8\170\170\170\170\168\168\173\168\170\32\0\170\170\85\213\223\223\207\120\246\191\255\255\255\255\239\255\227\255\191\255\255\127\79\224\76\251\85\254\255\255\237\1\128\246\23\160\3\204\255\255\255\255\255\187\159\235\255\94\10\128\254\255\7\10\200\7\12\196\215\79\255\77\113\61\234\50\17\254\15\36\4\16\236\255\238\48\141\226\255\255\255\223\255\255\255\255\255\31\246\207\207\255\255\159\252\127\168\255\255\255\255\255\255\255\255\183\239\255\239\191\251\255\253\253\247\227\243\3\31\63\144\38\0\0\248\239\255\255\239\127\254\127\110\254\255\143\114\254\255\127\252\255\255\255\255\248\240\255\219\255\255\255\223\207\251\255\254\219\255\52\255\255\255\255\3\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\254\255\255\255\237\255\255\223\237\255\251\255\255\255\255\255\255\51\2\192\255\255\255\255\255\255\207\254\255\255\255\255\255\31\0\0\0\0\0\0\0\0\0\0\0\240\255\255\255\255\255\255\255\7\0\0\0\0\0\0\0\0\0\0\0\240\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\241\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\3\0\0\0\0\0\0\0\0\0\0\0\254\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\253\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\103\255\255\255\255\245\255\63\52\253\255\236\125\6\180\191\243\255\255\255\255\255\255\255\255\255\255\255\255\255\251\255\255\255\255\255\255\255\95\255\255\222\31\255\255\255\255\255\95\143\255\131\254\255\255\255\255\255\255\255\255\255\255\255\255\247\127\255\255\253\39\35\24\126\223\255\255\255\255\249\238\255\246\251\255\252\155\125\254\239\64\237\87\16\0\190\254\255\247\207\255\255\255\255\255\17\0\0\0\4\136\7\4\48\0\176\255\126\1\254\255\255\199\255\255\255\255\255\255\253\15\0\0\3\0\0\96\136\63\253\255\3\0\0\245\231\255\113\249\4\0\244\1\0\0\0\0\0\0\0\255\255\255\255\207\255\255\255\255\255\15\0\0\0\0\0\254\255\255\255\255\255\255\255\255\255\255\255\63\128\0\0\224\255\255\63\0\0\0\0\0\240\255\255\255\255\255\3\0\0\0\28\7\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\2\0\0\0\0\0\0\8\0\16\192\0\7\0\0\0\8\0\0\0\64\0\0\0\128\0\0\0\0\128\2\0\0\0\24\2\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\248\3\0\0\0\0\0\0\0\0\252\255\95\0\2\16\192\1\0\0\0\0\0\0\0\0\0\0\248\255\223\255\247\255\255\255\255\3\8\0\192\225\255\251\127\189\255\255\255\159\247\255\239\211\47\84\0\2\2\4\0\66\9\0\89\0\128\7\128\0\32\128\9\49\63\55\55\248\159\126\255\29\252\75\252\4\6\247\255\255\255\255\255\63\226\223\255\255\255\255\255\255\255\255\63\255\255\255\255\63\0\0\0\0\231\249\223\193\233\124\244\127\63\252\255\127\120\254\255\239\255\254\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\254\255\251\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\247\223\255\255\191\143\193\159\231\29\31\16\128\215\245\191\255\239\255\255\15\126\232\193\135\243\63\190\255\8\255\23\255\253\103\192\254\255\191\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\63\179\255\255\255\255\255\255\255\255\255\127\143\223\1\0\0\0\0\224\255\255\255\255\255\255\255\255\255\255\255\255\255\1\0\0\0\0\0\0\0\254\175\255\254\223\157\255\255\255\255\255\255\255\255\31\0\0\0\0\0\0\128\0\0\0\0\2\0\48\0\16\0\0\254\255\255\255\255\46\32\124\2\252\239\255\255\255\79\255\225\251\255\255\255\255\255\255\244\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\249\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\166\239\254\1\0\0\0\0\0\0\0\0\0\0\0\84\63\228\1\144\217\183\62\0\60\57\0\0\254\1\0\0\0\220\255\255\255\255\255\119\0\8\0\193\255\255\127\0\1\6\0\0\0\124\0\16\0\4\0\0\0\0\0\8\0\254\255\255\255\191\255\63\254\239\255\215\15\255\255\247\31\129\129\201\255\255\255\255\95\254\3\8\8\2\0\0\0\0\0\0\191\0\0\0\0\0\0\1\0\0\224\31\0\7\128\255\15\252\255\255\255\223\255\255\255\255\255\255\255\255\255\255\253\127\239\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\199\12\32\32\93\8\169\6\17\128\136\7\144\254\255\247\255\255\255\255\135\243\255\126\255\255\255\255\255\255\15\254\255\255\63\191\255\255\255\255\255\255\255\7\0\224\255\249\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\249\255\127\207\255\255\255\255\255\255\255\255\255\143\255\255\255\255\127\255\255\255\255\63\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\254\255\255\255\255\255\255\255\255\255\255\255\255\255\255\143\255\255\3\0\0\0\0\0\0\0\0\0\0\16\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\127\254\231\255\255\255\255\255\255\255\255\199\255\255\255\255\255\255\255\255\15\242\239\223\255\207\255\255\255\255\255\255\255\255\255\247\247\255\255\255\255\241\31\192\255\255\231\255\255\255\255\255\255\255\63\92\7\182\58\241\255\255\255\255\255\255\47\127\237\191\231\158\230\207\255\225\231\220\127\246\127\127\255\255\255\55\194\255\255\255\255\255\127\128\255\1\194\249\30\136\32\18\1\226\63\252\255\255\255\255\255\255\255\255\255\127\0\0\0\0\0\0\0\0\0\16\16\16\18\194\255\0\18\144\255\31\62\33\246\127\255\255\254\127\255\127\249\247\253\252\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\234\255\171\170\170\170\154\170\170\170\170\170\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\199\33\57\248\67\255\255\255\255\255\255\215\159\253\252\247\255\255\255\255\255\255\255\255\255\255\251\255\255\255\255\255\255\255\255\255\255\239\255\255\244\255\255\255\231\3\2\1\30\255\127\254\239\127\255\225\255\239\255\248\251\251\255\255\241\231\255\255\127\244\211\193\249\255\127\115\249\255\255\255\255\255\255\255\255\7\80\200\127\0\255\255\255\223\0\0\255\255\3\0\0\0\58\48\252\221\255\255\255\252\255\255\255\255\255\255\255\255\255\255\255\191\248\255\121\252\255\255\255\255\255\255\255\255\255\255\255\253\207\127\24\240\255\127\243\255\255\244\255\255\255\223\249\255\255\255\255\255\255\255\255\255\255\255\255\247\0\240\127\63\156\204\255\127\199\254\241\255\127\0\160\199\236\45\192\255\220\254\255\249\251\255\255\255\255\255\255\15\127\254\254\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\253\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\127\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\248\239\255\0\0\253\191\63\227\252\127\247\255\143\255\31\0\184\63\243\255\79\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\191\255\127\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\191\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\251\255\255\255\255\255\255\79\254\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\187\223\255\255\3\0\224\255\255\255\253\255\71\248\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\239\127\255\255\255\255\255\255\255\255\63\252\3\0\0\240\0\254\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\251\255\255\255\255\255\255\255\255\63\0\0\6\0\3\0\0\140\1\192\8\10\0\66\4\60\114\36\192\244\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\127\32\0\16\0\0\128\24\4\12\32\16\32\72\0\33\3\34\76\129\0\64\128\64\16\98\1\96\8\3\0\1\2\8\59\16\96\12\4\128\32\0\68\16\3\144\1\10\0\134\8\0\228\64\224\233\254\255\255\255\255\255\255\255\191\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\251\255\255\255\255\255\255\255\255\255\255\255\219\15\240\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\207\127\250\204\255\255\255\127\126\112\1\118\0\240\255\31\0\0\0\0\0\0\48\62\16\16\0\0\0\2\66\0\0\0\0\0\0\0\0\0\0\16\0\0\0\128\127\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\128\127\0\128\0\0\0\0\0\0\0\146\249\127\128\80\68\123\3\0\0\0\0\8\0\0\192\191\8\0\0\7\248\32\0\127\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\248\1\0\128\1\0\0\0\2\0\0\0\0\0\0\0\0\0\0\0\36\0\0\0\0\0\0\224\255\255\255\161\13\6\0\32\248\0\120\152\69\193\1\32\240\255\11\15\252\255\255\255\255\255\31\255\191\121\202\1\179\1\0\0\0\0\0\2\0\0\4\112\0\1\0\4\0\8\112\0\254\3\255\0\36\121\31\64\7\0\0\0\128\173\255\1\0\0\6\180\255\255\255\255\253\231\0\251\255\239\255\28\196\175\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\240\255\255\255\255\255\255\255\255\255\255\255\253\3\0\0\116\0\0\0\0\0\30\0\0\28\64\250\255\241\255\248\231\255\255\253\255\255\248\255\1\248\255\223\223\247\255\6\254\255\255\255\255\255\255\255\254\255\255\255\255\255\255\255\255\255\255\128\0\5\255\255\255\128\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\223\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\7\0\0\0\0\64\118\240\7\0\0\0\0\0\128\255\255\255\3\0\0\0\0\64\128\0\249\255\255\191\159\255\127\255\255\7\0\0\0\255\255\253\255\255\255\247\255\63\255\255\248\252\252\255\127\0\0\39\57\255\7\0\0\0\0\0\128\255\3\60\16\0\115\254\255\255\255\255\255\129\7\244\255\255\255\255\115\192\0\252\255\255\255\255\255\255\255\255\255\255\255\255\255\255\253\255\255\255\255\255\255\255\255\255\255\255\255\254\129\76\190\1\0\0\249\255\255\0\0\0\239\33\0\0\0\0\0\224\255\7\48\240\3\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\248\175\255\255\255\255\255\255\191\251\191\139\3\120\0\0\248\211\240\224\112\48\8\3\193\31\96\0\0\0\255\255\255\255\55\0\0\30\0\0\0\0\128\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\15\128\0\0\0\4\0\0\0\0\0\0\0\96\98\16\16\0\0\241\15\232\255\223\255\255\127\255\255\255\3\0\0\0\0\0\0\0\0\0\0\224\255\255\255\255\255\255\255\255\255\255\239\255\255\255\255\63\255\255\255\254\255\255\255\255\255\255\255\255\7\0\2\0\254\15\0\8\0\240\255\255\255\255\255\255\255\255\3\194\0\129\200\255\255\255\255\3\0\8\17\0\0\0\0\254\255\191\128\127\2\126\192\1\0\0\8\128\254\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\252\255\255\255\255\255\255\255\255\255\255\255\1\0\58\0\32\192\255\254\255\255\3\112\1\16\16\64\128\0\1\80\1\0\18\0\0\0\1\0\0\0\0\0\0\0\0\32\7\0\0\0\0\0\0\0\0\0\0\0\0\32\0\128\7\0\0\0\0\0\0\0\0\0\224\143\10\16\226\7\192\19\0\0\4\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\128\255\255\255\255\255\239\248\64\27\255\255\255\255\31\0\0\216\255\253\255\1\0\184\132\135\4\192\3\0\128\88\32\160\243\255\191\221\3\0\128\255\255\255\99\17\254\253\255\39\0\248\247\255\159\128\240\65\254\191\3\0\240\255\255\255\255\255\255\255\255\255\0\0\0\0\0\3\4\0\130\40\255\1\0\0\128\6\192\15\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\16\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\63\0\252\253\255\11\36\4\128\255\63\224\255\3\240\0\255\255\255\249\0\1\248\255\255\47\0\0\33\0\3\1\128\128\240\253\63\248\15\2\0\224\1\3\224\9\0\0\0\0\0\0\0\4\0\244\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\31\0\2\208\32\0\248\253\241\1\0\0\0\0\0\0\0\0\0\0\0\0\126\248\255\33\0\0\0\0\0\0\0\0\240\195\255\0\252\255\255\255\255\15\0\0\28\224\255\207\23\248\223\127\190\255\126\255\63\255\253\255\255\255\255\223\255\254\255\255\255\255\105\1\0\0\0\248\15\0\0\0\0\16\0\4\0\0\0\0\4\128\0\0\200\0\92\4\0\0\17\16\0\224\255\255\247\255\255\255\255\159\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\1\62\255\30\128\255\255\255\255\255\252\31\224\31\224\31\224\31\224\31\224\31\0\192\63\192\63\192\63\192\255\255\254\249\255\255\231\255\255\255\255\255\255\255\255\255\255\255\255\255\31\127\139\80\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\15\255\255\122\136\34\48\4\224\3\0\0\0\0\0\6\17\45\64\164\1\87\4\0\0\0\176\0\128\7\4\0\0\0\4\0\0\0\112\1\0\0\0\48\40\127\145\31\0\252\255\255\255\163\252\127\254\4\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\7\0\0\2\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\253\7\100\136\35\1\0\69\128\255\253\239\31\132\15\1\0\0\128\126\132\24\224\255\255\31\0\9\32\128\0\0\0\8\0\0\192\112\0\0\128\0\0\16\212\2\0\0\0\0\136\66\180\255\0\0\0\128\129\0\0\0\252\120\252\207\49\0\40\0\16\0\106\224\236\127\0\0\1\0\0\0\0\0\0\0\4\0\0\248\19\0\0\0\0\0\8\0\0\64\1\128\65\1\2\0\0\0\152\255\255\0\2\2\0\0\0\0\0\0\112\240\255\255\255\255\255\255\255\255\255\255\255\255\255\255\239\135\161\236\64\0\0\248\255\3\4\248\127\252\255\255\255\131\255\255\255\255\255\255\255\255\255\255\255\255\255\127\254\255\255\255\255\255\255\15\254\255\127\0\0\0\227\255\255\255\255\251\255\241\255\255\255\251\255\223\255\31\0\0\64\56\0\0\0\14\0\0\128\9\129\255\127\1\32\128\255\255\255\255\255\255\255\255\255\255\255\255\255\255\223\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\191\1\0\0\240\255\255\255\255\255\255\255\255\255\255\255\255\255\255\7\0\0\0\15\16\2\248\127\0\0\0\8\224\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\127\14\64\0\128\122\253\207\1\0\0\48\156\247\255\255\255\255\255\255\23\0\60\0\192\255\255\255\255\255\255\255\255\255\255\255\255\255\255\31\224\255\255\255\255\255\255\255\255\255\255\255\255\255\7\0\0\0\0\24\106\64\29\192\192\252\255\63\0\192\254\191\62\240\191\252\255\255\255\255\255\255\255\255\255\255\143\0\0\96\0\192\0\0\0\0\160\1\236\225\235\1\4\128\136\227\243\255\249\255\255\255\255\255\255\255\255\255\127\240\193\255\255\15\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\48\0\0\248\255\255\255\255\255\255\255\255\255\255\255\255\255\255\221\63\255\255\239\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\63\197\96\255\255\255\255\247\255\191\255\255\255\255\255\255\255\255\255\255\255\135\255\255\127\0\0\128\255\255\255\223\255\127\255\255\255\223\255\255\255\255\255\255\255\255\255\255\255\127\255\255\255\255\255\255\255\255\255\255\255\254\255\255\63\255\255\255\47\200\24\0\24\32\192\255\255\255\223\0\0\0\97\2\4\116\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\1\0\225\15\224\255\255\11\28\204\253\119\0\0\0\176\223\60\255\255\255\255\255\255\255\255\255\255\255\255\255\255\63\0\0\0\56\0\64\0\0\0\16\0\128\187\63\1\0\0\240\255\127\128\127\250\157\1\0\0\0\0\6\0\0\192\3\0\221\237\15\0\8\0\0\0\0\0\0\160\251\253\255\255\255\255\255\255\255\63\0\112\4\56\192\1\0\0\62\0\0\32\4\6\216\255\255\127\0\1\0\6\224\127\0\1\124\207\47\0\12\224\255\223\255\255\255\255\255\255\255\255\232\31\190\255\255\255\255\255\255\255\255\255\255\255\223\255\255\255\255\255\255\255\255\255\255\3\8\0\48\237\15\32\0\0\205\121\0\1\0\200\251\127\185\176\255\227\255\255\255\255\127\64\128\239\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\131\251\255\255\255\255\31\247\31\120\254\255\255\255\255\255\255\255\255\255\255\255\255\255\195\255\255\255\255\255\255\255\255\255\63\248\255\255\255\255\191\254\255\127\255\51\255\255\255\255\255\255\255\255\255\231\15\254\247\225\127\65\240\191\15\255\3\254\239\255\143\245\253\255\255\127\252\241\127\0\1\0\0\192\166\223\255\127\0\0\0\0\0\0\0\0\0\0\0\0\128\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\15\252\255\255\255\255\255\255\255\255\255\255\255\255\255\143\255\255\255\255\127\0\0\0\192\255\255\255\131\199\191\15\48\0\128\1\4\0\0\0\3\0\0\64\191\0\2\0\0\79\2\0\1\236\255\255\63\0\8\224\255\255\255\255\3\0\20\0\0\254\255\63\4\4\0\240\31\0\0\0\0\0\0\227\0\0\0\1\0\64\160\15\248\31\120\0\196\255\255\254\255\255\239\39\0\0\4\4\0\0\0\0\0\0\248\255\255\255\199\255\0\128\1\28\0\4\0\6\4\255\254\225\31\18\129\224\165\255\255\255\255\255\191\0\132\249\15\16\160\1\255\7\0\246\16\0\224\255\1\0\216\255\247\255\255\255\255\255\255\255\255\255\1\254\127\1\120\45\127\255\255\255\255\247\63\128\0\192\255\255\255\255\255\63\0\1\32\0\0\128\15\6\0\224\3\192\3\252\207\123\255\255\95\199\129\3\24\129\255\144\99\198\240\255\255\255\255\255\255\255\255\227\219\32\14\255\255\15\255\255\255\255\255\255\255\255\225\255\255\255\255\255\255\255\255\1\0\0\0\0\0\0\0\0\0\0\0\0\240\251\255\255\255\255\255\255\255\255\255\255\255\31\252\225\255\255\255\255\255\255\253\239\255\255\255\201\255\255\255\15\255\239\63\1\254\255\255\255\71\225\243\255\63\0\64\12\0\0\0\0\0\224\252\31\64\254\255\255\255\255\255\255\255\255\255\6\0\192\56\0\62\0\2\132\248\175\255\35\0\0\0\0\1\0\0\0\2\0\252\255\0\96\128\0\0\0\0\0\224\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\192\255\255\255\255\255\255\255\255\255\255\255\255\255\170\250\175\170\254\170\191\170\170\170\90\85\181\170\170\94\117\85\85\213\170\170\170\170\234\170\170\174\170\170\254\90\85\117\85\85\85\85\85\87\253\87\85\85\0\230\227\117\0\46\160\226\248\83\22\0\0\184\6\0\0\0\0\0\0\0\4\0\0\0\0\72\6\0\12\0\255\31\224\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\48\255\255\15\0\0\224\6\8\240\21\32\192\246\94\6\48\153\7\0\248\255\255\255\255\255\1\0\0\0\192\1\252\255\31\128\12\96\104\192\246\111\11\60\0\224\255\227\15\240\255\255\255\255\255\255\255\255\255\1\0\254\255\255\63\112\40\234\248\195\15\0\0\0\1\36\243\255\157\255\255\255\255\255\255\255\255\255\255\255\255\31\97\128\1\44\244\246\158\72\136\255\30\254\255\255\255\255\0\0\0\0\2\252\255\255\127\128\130\134\1\247\7\188\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\3\0\32\192\32\218\0\0\0\0\15\128\15\254\34\64\0\1\0\0\128\79\52\0\192\0\0\253\255\255\7\8\240\255\239\0\0\0\0\0\0\252\3\3\0\0\0\0\0\0\249\255\255\255\255\231\255\255\255\255\192\9\60\6\4\132\231\255\255\255\127\240\255\255\127\255\121\135\128\240\255\255\128\223\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\63\252\239\255\207\0\128\1\240\255\255\255\7\24\0\0\0\0\48\0\0\0\0\0\0\0\30\134\255\255\255\255\255\255\255\255\255\255\255\255\255\63\4\64\0\0\4\128\0\49\192\1\32\254\127\255\255\255\255\255\255\255\255\255\255\255\255\255\1\255\253\31\254\255\247\255\255\255\255\255\255\255\1\124\0\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\143\224\191\251\255\175\3\252\7\255\199\255\247\255\255\255\0\25\64\248\255\255\240\3\3\0\247\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\15\0\0\0\252\255\255\31\28\0\0\0\0\0\0\0\192\255\255\255\0\128\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\15\0\0\0\252\255\255\31\28\0\0\0\0\0\0\0\192\255\255\255\0\0\0\224\7\0\0\255\1\0\0\252\15\252\31\0\32\0\0\0\0\8\224\255\215\207\239\1\1\0\0\0\0\0\0\0\0\0\0\0\0\0\0\16\2\1\0\0\0\0\0\128\188\247\255\195\255\255\55\0\0\0\0\0\0\252\255\255\255\255\255\255\255\255\223\0\0\0\254\255\255\255\255\255\255\255\15\0\0\0\16\254\255\127\17\66\255\5\0\0\16\0\64\253\255\247\249\223\1\8\255\63\2\255\223\14\191\255\239\6\244\254\203\255\255\255\192\255\127\184\255\63\16\30\248\255\255\255\255\255\255\255\255\255\255\255\255\255\0\0\0\128\255\31\192\0\0\0\0\0\0\0\0\16\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\64\243\224\23\0\0\0\224\255\255\7\0\0\0\0\0\0\0\0\0\0\0\20\0\0\0\0\252\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\3\0\0\0\0\0\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\63\0\0\0\0\0\0\0\0\0\0\0\0\0\0\254\255\255\255\255\255\255\255\255\255\255\255\255\255\15\0\0\0\0\0\0\0\0\0\0\0\0\0\128\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\15\224\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\43\41\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\15\192\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\253\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\239\7\0\0\0\0\0\0\0\0\0\0\0\0\0\64\195\161\0\0\48\3\37\0\0\0\192\249\255\255\255\255\255\255\255\255\255\255\255\255\255\255\251\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\31\0\0\0\0\0\0\0\0\0\0\0\64\0\0\0\8\1\4\0\0\0\112\4\0\0\0\128\3\1\0\0\0\6\0\0\0\0\132\3\96\0\0\0\240\14\20\0\254\3\0\0\192\1\60\63\0\240\39\240\255\255\255\255\255\255\255\159\255\255\255\255\255\255\255\255\255\255\255\255\255\15\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\128\255\3\0\0\0\0\255\103\9\0\0\0\0\0\0\64\2\0\0\240\131\207\255\255\255\255\255\255\175\7\0\0\72\0\0\8\0\0\0\0\0\0\0\0\0\0\128\4\128\5\68\0\0\3\0\176\127\0\0\0\32\0\224\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\223\0\0\16\0\0\0\0\0\0\0\128\240\124\127\5\0\36\224\255\3\0\0\0\224\255\255\255\255\255\255\255\255\255\255\255\255\255\254\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\225\63\112\128\127\128\1\102\240\223\1\250\1\4\16\252\255\135\255\247\251\251\255\255\1\0\0\56\130\127\255\255\255\255\31\251\255\207\225\254\255\95\251\253\255\252\15\6\0\0\0\0\192\255\253\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\191\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\127\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\127\0\224\255\252\31\248\79\255\15\0\240\79\254\255\255\255\255\255\255\255\255\255\255\255\159\255\15\0\0\4\2\192\207\127\255\193\0\28\0\0\0\0\0\0\0\0\0\0\24\0\0\0\0\0\0\0\0\0\0\230\255\255\255\255\251\3\0\0\1\0\0\0\240\188\128\0\0\0\252\255\255\255\255\255\255\255\255\15\0\0\0\224\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\0\0\0\0\0\0\0\0\128\51\8\0\0\0\124\31\128\67\36\0\0\0\0\248\1\40\0\0\0\6\0\0\0\0\0\0\0\0\0\2\4\32\0\0\0\0\0\0\0\0\0\0\0\0\0\132\0\0\131\0\0\0\64\0\248\125\0\0\240\255\63\0\64\2\128\255\1\0\0\224\211\1\0\8\0\0\1\0\124\240\15\0\0\4\6\48\160\8\0\240\8\0\0\0\0\0\12\0\0\0\128\250\135\254\0\0\0\32\0\88\0\0\0\0\0\0\0\0\0\32\36\32\64\0\0\1\4\196\20\0\0\0\128\7\0\32\6\162\3\112\0\240\255\255\255\255\255\255\255\255\127\230\255\255\1\224\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\31\192\1\0\8\2\248\255\31\224\255\255\255\255\255\31\0\0\96\14\0\3\80\0\64\18\0\0\0\0\9\10\12\0\0\0\0\0\0\0\0\0\0\0\20\128\128\36\192\7\80\193\128\1\32\4\0\0\0\0\128\240\127\23\0\0\224\1\0\0\0\56\254\3\0\0\0\252\7\248\39\128\255\191\227\0\0\0\193\247\1\234\15\0\60\0\60\192\1\0\0\192\125\9\254\195\193\255\255\247\255\255\255\191\255\239\63\192\134\24\48\0\255\7\0\160\242\247\255\255\255\251\255\255\255\255\255\255\255\255\255\223\255\251\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\251\255\63\48\0\224\147\195\64\2\96\224\31\0\24\0\0\0\0\0\16\8\0\0\0\0\132\116\192\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\63\240\255\255\255\255\255\255\255\223\252\255\255\7\224\255\255\255\15\0\0\0\0\0\0\8\0\0\0\48\0\0\0\0\0\0\0\0\0\158\160\0\16\0\104\34\252\127\0\0\9\0\0\0\0\0\0\64\14\96\2\0\0\130\79\57\64\24\4\120\0\0\42\0\10\0\0\128\0\1\144\8\2\0\226\0\224\7\255\255\255\255\255\145\132\96\254\1\0\0\66\9\0\0\0\0\1\0\128\1\192\255\255\255\255\255\255\255\255\255\127\0\0\130\5\0\0\0\0\0\0\0\0\0\0\16\0\0\0\0\0\4\0\0\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\31\0\0\192\255\255\63\0\11\0\2\0\0\120\24\56\0\0\4\0\246\65\2\192\255\255\255\3\192\62\24\2\0\0\0\238\243\255\15\122\0\192\1\16\228\5\0\4\0\24\0\142\238\255\15\0\0\0\0\0\0\192\0\0\0\0\0\64\0\0\128\251\31\0\0\114\1\72\2\2\152\12\0\255\63\239\3\3\28\253\255\255\255\255\121\55\64\232\255\255\247\63\5\2\48\254\255\28\108\213\255\68\32\30\190\56\0\255\7\76\236\1\0\0\0\12\0\112\224\255\255\255\255\15\240\239\237\65\254\255\127\23\255\220\15\0\128\255\223\191\223\1\64\248\255\255\255\198\240\255\255\255\111\255\255\255\141\255\255\255\255\255\207\127\135\0\64\254\255\128\207\185\230\247\127\245\255\255\255\254\255\63\126\255\255\255\255\95\223\127\255\255\254\255\87\254\255\131\255\255\255\255\255\255\247\55\6\0\96\255\255\253\255\255\31\254\255\1\0\158\31\250\248\223\0\83\230\175\255\255\7\255\127\158\1\28\200\255\255\247\255\255\255\225\63\192\219\1\252\239\255\255\255\255\255\253\255\255\255\255\249\79\255\127\120\251\249\255\255\161\29\249\157\24\0\64\6\120\255\255\253\247\7\255\255\255\207\64\243\255\255\255\255\38\0\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\127\254\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\204\185\5\243\255\255\255\255\243\255\255\255\223\255\245\191\255\255\255\255\255\247\125\223\231\255\255\255\255\251\190\239\255\255\255\255\127\223\247\253\255\255\255\255\239\251\190\255\255\255\255\255\125\223\247\255\255\255\255\191\239\251\190\32\29\3\129\64\32\16\240\255\255\255\255\255\255\255\255\35\0\0\0\28\0\0\224\255\63\95\63\255\255\255\255\159\255\7\254\255\127\248\254\127\255\255\221\251\255\63\72\146\31\142\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\195\255\255\255\255\255\255\255\251\127\4\236\255\255\255\255\127\255\255\255\127\32\248\254\252\14\251\255\255\251\127\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\253\253\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\23\252\255\255\255\191\255\255\251\127\224\252\244\255\255\255\255\255\255\191\191\190\231\252\255\255\255\255\255\255\239\255\255\255\255\255\255\223\255\255\255\255\255\255\255\255\127\240\255\191\254\255\255\255\255\255\255\231\255\190\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\253\191\219\254\249\111\255\255\255\191\254\243\255\255\255\7\0\220\255\255\255\255\255\255\255\255\191\255\255\255\247\253\255\255\255\255\255\255\255\255\255\255\223\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\254\255\255\191\255\63\255\127\0\0\254\19\56\1\240\247\255\255\255\255\15\128\192\143\96\0\254\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\31\242\255\255\255\255\255\255\255\47\47\252\255\255\255\51\191\127\254\255\255\253\255\255\0\0\244\255\241\255\95\247\255\255\63\254\161\255\255\253\254\255\255\255\255\253\255\255\251\251\223\255\255\255\255\255\131\255\255\255\255\127\255\255\255\255\15\96\60\0\239\255\3\224\214\190\3\148\253\247\242\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\253\127\255\199\127\255\255\255\255\255\255\255\245\255\255\142\220\15\255\255\255\255\255\255\63\128\255\255\254\255\127\255\255\251\255\255\255\239\223\255\255\255\255\255\255\255\255\255\255\47\255\255\255\255\255\255\255\255\255\255\255\255\255\255\251\255\255\255\255\255\254\255\255\255\255\255\255\255\255\255\255\127\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\253\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\247\255\255\63\254\7\252\255\131\131\239\47\126\0\252\10\232\240\127\248\255\255\255\255\255\255\255\255\251\127\18\184\208\209\223\63\31\156\31\0\240\255\255\15\32\0\0\228\127\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\19\0\0\0\0\0\0\0\0\0\0\225\67\128\128\249\239\15\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\64\0\0\16\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\129\255\223\191\249\7\16\4\244\255\255\103\252\255\255\247\218\251\243\255\255\163\7\12\16\130\252\255\255\255\255\255\255\255\255\255\255\232\255\255\255\24\0\0\252\75\20\224\255\255\255\255\15\128\251\255\255\255\240\249\236\240\207\255\16\242\255\17\0\0\248\14\18\0\128\72\255\47\0\0\96\1\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\12\35\6\16\0\2\0\0\0\0\0\0\0\0\8\112\208\255\255\3\124\0\60\1\16\32\0\0\0\48\113\4\0\0\0\248\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\127\0\0\0\0\0\0\240\0\0\0\0\0\0\0\2\255\7\0\8\227\255\255\255\255\255\255\255\255\255\127\62\242\255\31\112\254\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\231\240\249\255\255\255\127\2\0\160\14\0\0\0\17\127\192\195\255\255\255\255\255\255\61\224\217\255\255\255\255\255\255\255\255\255\255\255\255\255\255\7\188\6\6\128\255\255\255\255\255\31\252\31\48\229\223\55\190\235\251\250\255\255\255\255\255\255\255\255\255\239\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\127\251\255\127\3\2\192\208\149\255\255\255\255\95\199\191\126\255\224\255\252\131\127\72\1\0\240\148\63\128\255\255\0\0\0\0\0\0\0\255\255\255\255\84\6\0\254\195\253\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\227\193\255\255\255\255\35\240\111\251\0\0\254\191\255\127\11\224\127\252\255\198\0\0\250\1\30\16\0\67\0\0\191\255\255\227\49\255\255\255\179\193\13\126\39\1\96\0\0\0\0\0\0\0\0\0\0\0\0\176\234\255\27\254\127\4\0\16\0\2\0\0\0\0\0\0\128\130\0\0\3\68\0\0\0\0\0\0\0\0\2\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\4\0\0\0\0\0\0\0\16\128\3\0\0\0\0\0\0\0\0\64\0\0\0\0\0\0\0\0\0\224\255\255\255\15\254\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\31\0\0\0\4\0\0\0\0\0\0\0\0\0\252\255\247\255\19\248\223\63\223\3\0\0\166\229\251\255\6\16\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\129\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\64"

local CONST_ITEMS_PER_SCAN = CONST_ITEMS_PER_SCAN_CLIENT
 
local PATTERN_itemid = "item:(%-?%d+)"
local FORMAT_itemid = "item:%d:0:0:0:0:0:0:0:0:0:0"

local items = LibInventory.items

local function getbaseid(link)
	if link then
		if type(link) == "number" then return link end
		local baseid = string_match(link, PATTERN_itemid)
		if not baseid then
			baseid = link
		end
		return tonumber(baseid)
	end
	return
end


-- -----
-- public API
-- -----
LibInventory.GetItemBaseId = getbaseid

function LibInventory:GetItems(force_rescan)
	if force_rescan then
		self:BuildLists(true)
	end
	return self.items
end

function LibInventory:GetTypesTables()
	return self.types_tree, self.types_base, self.types_sub, self.types_slot
end

function LibInventory:GetCounts()
	return self.count_known, self.count_total, self.highest_id, #self.itemsValidIdsClient, #self.itemsValidIdsServer, #self.itemsRescan
end

function LibInventory:QueryItem(item)
	item = getbaseid(item)
	if not item then return false end
	local found, newType = self:ScanItem(item)
	if newType then
		self:UpdateTypesTree()
	end
	return found
end

function LibInventory:GetStatus()
	return self.status
end

function LibInventory:IsValidItem(id)
	id = getbaseid(id)
	if (id > CONST_ITEMS_MAX_ID) then return false end
	id = id - 1
	local charIndex = math_floor(id / 8) + 1
	local char = string_byte(itemsValid, charIndex)
	local mask = math_pow(2,(id % 8))
	return bit_band(char, mask) > 0
end

function LibInventory:IsClientItem(id)
	id = getbaseid(id)
	if (id > CONST_ITEMS_MAX_ID_CLIENT) then return false end
	id = id - 1
	local charIndex = math_floor(id / 8) + 1
	local char = string_byte(itemsClient, charIndex)
	local mask = math_pow(2,(id % 8))
	return bit_band(char, mask) > 0
end

function LibInventory:RescanServer()
	if (self.status ~= self.STATUS_READY) then return end
	self:EnableEvents()
	if not InCombatLockdown() then
		self.frame:Show()
	end
	self.status = self.STATUS_SCANNING_SERVER
	self.callbacks:Fire("LibInventory_StatusChanged", self.status)
end

-- -----
-- data storing
-- -----
function LibInventory:BuildLists(force_full_scan)
	if (self.status == self.READY) then return end
	if (self.status == self.STATUS_INITIALIZING) then
		local count_total = self.count_total
		local highest_id = self.highest_id
		local itemsLastScanned = self.itemsLastScanned or 0
		local itemsValidIdsClient, itemsValidIdsServer = self.itemsValidIdsClient, self.itemsValidIdsServer
		local maxScan = min(itemsLastScanned + 2500, CONST_ITEMS_MAX_ID)
		for i = itemsLastScanned + 1, maxScan do
-- 			if GetItemIcon(i) then
			if self:IsValidItem(i) then
				count_total = count_total + 1
				highest_id = i
				if self:IsClientItem(i) then
					table_insert(itemsValidIdsClient, i)
				else
					table_insert(itemsValidIdsServer, i)
				end
			end
		end
		self.itemsLastScanned = maxScan
		self.count_total = count_total
		self.highest_id = highest_id
		if (self.itemsLastScanned == CONST_ITEMS_MAX_ID) then
			self.itemsLastScanned = nil
			self.status = self.STATUS_QUERYING_CLIENT
--			self.status = self.STATUS_QUERYING_SERVER
			self.callbacks:Fire("LibInventory_StatusChanged", self.status)
			collectgarbage("collect")
		end
		return
	end

	local scanList
	if (self.status == self.STATUS_QUERYING_CLIENT or self.status == self.STATUS_SCANNING_CLIENT) then
		scanList = self.itemsValidIdsClient
	else
		scanList = self.itemsValidIdsServer
	end

	local scanCount = 0
	local updateTypes = false
	while (#scanList > 0 and (force_full_scan or scanCount < CONST_ITEMS_PER_SCAN)) do
		local id = table_remove(scanList, math_random(#scanList))
--		local id = table_remove(scanList)
		scanCount = scanCount + 1
		local found, newType = self:ScanItem(id)
		if (not found) then
			table_insert(self.itemsRescan, id)
		end
		updateTypes = updateTypes or newType
	end

	if (updateTypes) then self:UpdateTypesTree() end

	if (#scanList == 0) then
		if (self.status == self.STATUS_QUERYING_CLIENT) then
			self.itemsValidIdsClient, self.itemsRescan = self.itemsRescan, self.itemsValidIdsClient
			collectgarbage("collect")
			self.status = self.STATUS_SCANNING_CLIENT
			self.callbacks:Fire("LibInventory_StatusChanged", self.status)
		elseif (self.status == self.STATUS_SCANNING_CLIENT) then
 			CONST_ITEMS_PER_SCAN = CONST_ITEMS_PER_SCAN_SERVER
			self.itemsValidIdsClient, self.itemsRescan = self.itemsRescan, self.itemsValidIdsClient
			collectgarbage("collect")
			self.status = self.STATUS_QUERYING_SERVER
			self.callbacks:Fire("LibInventory_StatusChanged", self.status)
		elseif (self.status == self.STATUS_QUERYING_SERVER) then
			self.itemsValidIdsServer, self.itemsRescan = self.itemsRescan, self.itemsValidIdsServer
			collectgarbage("collect")
			self.status = self.STATUS_SCANNING_SERVER
			self.callbacks:Fire("LibInventory_StatusChanged", self.status)
		elseif (self.status == self.STATUS_SCANNING_SERVER) then
			self.itemsValidIdsServer, self.itemsRescan = self.itemsRescan, self.itemsValidIdsServer
			collectgarbage("collect")
-- 			if (#(self.itemsRescan) == 0) then
				self.status = self.STATUS_READY
				self.callbacks:Fire("LibInventory_StatusChanged", self.status)
				self.frame:UnregisterAllEvents()
				self.frame:Hide()
--			end
		end
	end
end

function LibInventory:ScanItem(id)
	if (not items[id]) then
--		local itemName, itemLink, itemRarity, itemLevel, itemMinLevel, itemType, itemSubType, itemStackCount, itemEquipLoc, itemTexture, itemSellPrice = GetItemInfo(id)
		local itemName, _, _, _, _, itemType, itemSubType, _, itemEquipLoc, _, _ = GetItemInfo(id)
		if (itemName and itemName ~= "") then -- cached item
			itemType, itemSubType, itemEquipLoc = tostring(itemType), tostring(itemSubType), _G[itemEquipLoc]
			if (not itemType or itemType == "") then
				itemType = self.LOCALE_INVTYPE_OTHER
			end
			if (not itemSubType or itemSubType == "") then
				itemSubType = self.LOCALE_INVTYPE_OTHER
			end
			if (not itemEquipLoc or itemEquipLoc == "") then
				itemEquipLoc = self.LOCALE_INVTYPE_OTHER
			end

			items[id] = true
			self.count_known = self.count_known + 1

--			GetItemStats("item:"..id, self.itemStatsTable)

			local newType = false
			local types_tree = self.types_tree
			if (not types_tree[itemType]) then
				types_tree[itemType] = {}
				newType = true
			end
			if (not types_tree[itemType][itemSubType]) then
				types_tree[itemType][itemSubType] = {}
				newType = true
			end
			if (not types_tree[itemType][itemSubType][itemEquipLoc]) then
				types_tree[itemType][itemSubType][itemEquipLoc] = true
				newType = true
			end
			return true, newType
		else --item wasn't cached, yet; GetItemInfo call caused a request
			return false, false
		end
	else
		return true, false
	end
end

function LibInventory:UpdateTypesTree()
	local types_tree = self.types_tree
	local types_base = table_wipe(self.types_base)
	local types_sub = table_wipe(self.types_sub)
	local types_slot = table_wipe(self.types_slot)

	for basetype, subtypes in pairs(types_tree) do
		if basetype ~= 1 then
			table_insert(types_base, basetype)
			local subtypesort = subtypes[1] and table_wipe(subtypes[1]) or {}
			local hasinvtypes = false
			for subtype, invtypes in pairs(subtypes) do
				if subtype ~= 1 then
					table_insert(subtypesort, tostring(subtype))
					local invtypesort = invtypes[1] and table_wipe(invtypes[1]) or {}
					for invtype, _ in pairs(invtypes) do
						if invtype ~= 1 then
							table_insert(invtypesort, tostring(invtype))
						end
					end
					if #invtypesort > 1 then
						table_sort(invtypesort)
						if (not types_slot[basetype]) then
							types_slot[basetype] = {}
						end
						types_slot[basetype][subtype] = invtypesort
						hasinvtypes = true
					end
					invtypes[1] = invtypesort
				end
			end
			if #subtypesort > 1 or hasinvtypes then
				table_sort(subtypesort)
				types_sub[basetype] = subtypesort
			end
			subtypes[1] = subtypesort
		end
	end
	table_sort(self.types_base)
	types_tree[1] = types_base
	self.callbacks:Fire("LibInventory_TypesUpdated")
end


-- -----
-- OnEvent and OnUpdate handlers / event registering
-- -----
local eventmap = {
-- other
	["PLAYER_ENTERING_WORLD"] = "PLAYER_ENTERING_WORLD",
	["PLAYER_LEAVING_WORLD"] = "PLAYER_LEAVING_WORLD",
	["PLAYER_REGEN_ENABLED"] = "PLAYER_REGEN_ENABLED",
	["PLAYER_REGEN_DISABLED"] = "PLAYER_REGEN_DISABLED",
}

LibInventory.frame:SetScript("OnEvent", function(self, event, ...)
	local eventfunc = eventmap[event]
	if eventfunc then
		LibInventory[eventfunc](LibInventory, ...)
	end
end)

function LibInventory:EnableEvents()
	for event in pairs(eventmap) do
		self.frame:RegisterEvent(event)
	end
end
LibInventory:EnableEvents()

local update_throttle = 30
LibInventory.frame:SetScript("OnUpdate", function(self, elapsed)
	update_throttle = update_throttle - elapsed
	if (update_throttle > 0) then return end
	update_throttle = 0.1
	LibInventory:BuildLists()
end)

LibInventory.frame:Hide()


-- -----
-- event functions
-- -----
function LibInventory:PLAYER_ENTERING_WORLD()
--~ 	self:BuildLists(true)
	if not InCombatLockdown() then
		update_throttle = 15
		LibInventory.frame:Show()
	end
end

function LibInventory:PLAYER_LEAVING_WORLD()
	LibInventory.frame:Hide()
end

function LibInventory:PLAYER_REGEN_ENABLED()
	update_throttle = 5
	LibInventory.frame:Show()
end

function LibInventory:PLAYER_REGEN_DISABLED()
	LibInventory.frame:Hide()
end
